@@ -27,7 +27,7 @@ except ImportError:
 from errno import EAGAIN, ECONNRESET
 import os
 
-__version__ = "0.5.3"
+__version__ = "0.5.4"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_HTTPServer.git"
 
 
@@ -247,7 +247,8 @@ class HTTPResponse:
             while bytes_read := file.read(2048):
                 self._send_bytes(conn, bytes_read)
 
-    def _send_bytes(self, conn, buf):  # pylint: disable=no-self-use
+    @staticmethod
+    def _send_bytes(conn, buf):
         bytes_sent = 0
         bytes_to_send = len(buf)
         view = memoryview(buf)
